@@ -1,3 +1,5 @@
+mod store;
 mod tile_atlas;
 
-pub use tile_atlas::{TileAtlasBuilder, TileAtlasBuilderError};
\ No newline at end of file
+pub use store::TextureStore;
+pub use tile_atlas::{TileAtlasBuilder, TileAtlasBuilderError};
